@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2018 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -10,19 +10,22 @@
 
 #include "squid.h"
 #include "acl/Checklist.h"
+#include "acl/Options.h"
 #include "acl/UserData.h"
 #include "ConfigParser.h"
-#include "Debug.h"
+#include "debug/Stream.h"
 #include "globals.h"
 #include "sbuf/Algorithms.h"
 #include "util.h"
 
+Acl::BooleanOptionValue ACLUserData::CaseInsensitive_;
+
 bool
 ACLUserData::match(char const *user)
 {
     debugs(28, 7, "user is " << user << ", case_insensitive is " << flags.case_insensitive);
 
-    if (user == NULL || strcmp(user, "-") == 0)
+    if (user == nullptr || strcmp(user, "-") == 0)
         return 0;
 
     if (flags.required) {
@@ -50,7 +53,9 @@ ACLUserData::dump() const
 
     sl.insert(sl.end(), userDataNames.begin(), userDataNames.end());
 
-    debugs(28,5, "ACLUserData dump output: " << SBufContainerJoin(userDataNames,SBuf(" ")));
+    debugs(28,5, "ACLUserData dump output: " <<
+           JoinContainerToSBuf(userDataNames.begin(), userDataNames.end(),
+                               SBuf(" ")));
     return sl;
 }
 
@@ -73,12 +78,22 @@ ACLUserData::ACLUserData() :
     flags.required = false;
 }
 
+const Acl::Options &
+ACLUserData::lineOptions()
+{
+    static auto MyCaseSensitivityOption = Acl::CaseSensitivityOption();
+    static const Acl::Options MyOptions = { &MyCaseSensitivityOption };
+    MyCaseSensitivityOption.linkWith(&CaseInsensitive_);
+    return MyOptions;
+}
+
 void
 ACLUserData::parse()
 {
     debugs(28, 2, "parsing user list");
+    flags.case_insensitive = bool(CaseInsensitive_);
 
-    char *t = NULL;
+    char *t = nullptr;
     if ((t = ConfigParser::strtokFile())) {
         SBuf s(t);
         debugs(28, 5, "first token is " << s);
@@ -136,9 +151,3 @@ ACLUserData::empty() const
     return userDataNames.empty();
 }
 
-ACLData<char const *> *
-ACLUserData::clone() const
-{
-    return new ACLUserData;
-}
-
