@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1996-2020 The Squid Software Foundation and contributors
+ * Copyright (C) 1996-2023 The Squid Software Foundation and contributors
  *
  * Squid software is distributed under GPLv2+ license and includes
  * contributions from numerous individuals and organizations.
@@ -59,17 +59,17 @@ read_passwd_file(const char *passwdfile)
     }
     unsigned int lineCount = 0;
     buf[HELPER_INPUT_BUFFER-1] = '\0';
-    while (fgets(buf, sizeof(buf)-1, f) != NULL) {
+    while (fgets(buf, sizeof(buf)-1, f) != nullptr) {
         ++lineCount;
         if ((buf[0] == '#') || (buf[0] == ' ') || (buf[0] == '\t') ||
                 (buf[0] == '\n'))
             continue;
         user = strtok(buf, ":\n\r");
-        if (user == NULL) {
+        if (user == nullptr) {
             fprintf(stderr, "ERROR: Missing user name at %s line %d\n", passwdfile, lineCount);
             continue;
         }
-        passwd = strtok(NULL, ":\n\r");
+        passwd = strtok(nullptr, ":\n\r");
         if ((strlen(user) > 0) && passwd) {
             usermap[user] = passwd;
         }
@@ -84,7 +84,7 @@ main(int argc, char **argv)
     time_t change_time = -1;
     char buf[HELPER_INPUT_BUFFER];
     char *user, *passwd, *p;
-    setbuf(stdout, NULL);
+    setbuf(stdout, nullptr);
     if (argc != 2) {
         fprintf(stderr, "Usage: ncsa_auth <passwordfile>\n");
         exit(EXIT_FAILURE);
@@ -93,8 +93,8 @@ main(int argc, char **argv)
         fprintf(stderr, "FATAL: cannot stat %s\n", argv[1]);
         exit(EXIT_FAILURE);
     }
-    while (fgets(buf, HELPER_INPUT_BUFFER, stdin) != NULL) {
-        if ((p = strchr(buf, '\n')) != NULL)
+    while (fgets(buf, HELPER_INPUT_BUFFER, stdin) != nullptr) {
+        if ((p = strchr(buf, '\n')) != nullptr)
             *p = '\0';      /* strip \n */
         if (stat(argv[1], &sb) == 0) {
             if (sb.st_mtime != change_time) {
@@ -102,11 +102,11 @@ main(int argc, char **argv)
                 change_time = sb.st_mtime;
             }
         }
-        if ((user = strtok(buf, " ")) == NULL) {
+        if ((user = strtok(buf, " ")) == nullptr) {
             SEND_ERR("");
             continue;
         }
-        if ((passwd = strtok(NULL, "")) == NULL) {
+        if ((passwd = strtok(nullptr, "")) == nullptr) {
             SEND_ERR("");
             continue;
         }
@@ -120,7 +120,7 @@ main(int argc, char **argv)
         std::string stored_pass = userpassIterator->second;
         const char *salted = stored_pass.c_str(); // locally stored version contains salt etc.
 
-        char *crypted = NULL;
+        char *crypted = nullptr;
 #if HAVE_CRYPT
         size_t passwordLength = strlen(passwd);
         // Bug 3831: given algorithms more secure than DES crypt() does not truncate, so we can ignore the bug 3107 length checks below
